class SpamAssassinRule(object):
    """SpamAssassinRule.

    :param score:
    :type score: float
    :param rule:
    :type rule: str
    :param description:
    :type description: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.score = data.get('score', 0.0)
        self.rule = data.get('rule', None)
        self.description = data.get('description', None)



import os
from unittest import TestCase
from mailosaur import MailosaurClient
from mailosaur.models import ServerCreateOptions, MailosaurException


class ErrorsTest(TestCase):
    @classmethod
    def setUpClass(self):
        self.api_key = os.getenv('MAILOSAUR_API_KEY')
        self.base_url = os.getenv('MAILOSAUR_BASE_URL')

        if self.api_key is None:
            raise Exception(
                "Missing necessary environment variables - refer to README.md")

    def test_unauthorized(self):
        client = MailosaurClient('invalid_key', self.base_url)

        with self.assertRaises(MailosaurException) as context:
            client.servers.list()

        self.assertEqual(
            'Authentication failed, check your API key.', context.exception.message)

    def test_not_found(self):
        client = MailosaurClient(self.api_key, self.base_url)

        with self.assertRaises(MailosaurException) as context:
            client.servers.get('not_found')

        self.assertEqual(
            'Not found, check input parameters.', context.exception.message)

    def test_bad_request(self):
        client = MailosaurClient(self.api_key, self.base_url)

        with self.assertRaises(MailosaurException) as context:
            options = ServerCreateOptions()
            client.servers.create(options)

        self.assertEqual(
            '(name) Servers need a name\r\n', context.exception.message)



class UsageTransaction(object):
    """UsageTransaction.

    :param timestamp:
    :type timestamp: datetime
    :param email:
    :type email: int
    :param sms:
    :type sms: int
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.timestamp = data.get('timestamp', None)
        self.email = data.get('email', None)
        self.sms = data.get('sms', None)



class ServerCreateOptions(object):
    """ServerCreateOptions.

    :param name: A name used to identify the server.
    :type name: str
    """

    def __init__(self, name=None):
        self.name = name

    def to_json(self):
        return {
            'name': self.name
        }



from .spam_filter_results import SpamFilterResults

class SpamAnalysisResult(object):
    """SpamAnalysisResult.

    :param spam_filter_results:
    :type spam_filter_results: ~mailosaur.models.SpamFilterResults
    :param score:
    :type score: float
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.spam_filter_results = SpamFilterResults(data.get('spamFilterResults', None))
        self.score = data.get('score', 0.0)



from .spam_assassin_rule import SpamAssassinRule
from .spam_filter_results import SpamFilterResults
from .spam_analysis_result import SpamAnalysisResult
from .deliverability_report import DeliverabilityReport
from .mailosaur_exception import MailosaurException
from .message_address import MessageAddress
from .link import Link
from .code import Code
from .image import Image
from .message_content import MessageContent
from .attachment import Attachment
from .message_header import MessageHeader
from .metadata import Metadata
from .message import Message
from .message_summary import MessageSummary
from .message_list_result import MessageListResult
from .message_create_options import MessageCreateOptions
from .message_forward_options import MessageForwardOptions
from .message_reply_options import MessageReplyOptions
from .search_criteria import SearchCriteria
from .server import Server
from .server_list_result import ServerListResult
from .server_create_options import ServerCreateOptions
from .usage_account_limits import UsageAccountLimits
from .usage_account_limit import UsageAccountLimit
from .usage_transaction_list_result import UsageTransactionListResult
from .usage_transaction import UsageTransaction
from .device import Device
from .device_list_result import DeviceListResult
from .device_create_options import DeviceCreateOptions
from .otp_result import OtpResult
from .preview_list_result import PreviewListResult
from .email_client_list_result import EmailClientListResult
from .email_client import EmailClient
from .preview_request_options import PreviewRequestOptions

__all__ = [
    'SpamAssassinRule',
    'SpamFilterResults',
    'SpamAnalysisResult',
    'DeliverabilityReport',
    'MailosaurException',
    'MessageAddress',
    'Link',
    'Code',
    'Image',
    'MessageContent',
    'Attachment',
    'MessageHeader',
    'Metadata',
    'Message',
    'MessageSummary',
    'MessageListResult',
    'MessageCreateOptions',
    'MessageForwardOptions',
    'MessageReplyOptions',
    'PreviewRequestOptions',
    'SearchCriteria',
    'Server',
    'ServerListResult',
    'ServerCreateOptions',
    'UsageAccountLimits',
    'UsageAccountLimit',
    'UsageTransactionListResult',
    'UsageTransaction',
    'Device',
    'DeviceListResult',
    'DeviceCreateOptions',
    'OtpResult',
    'PreviewListResult',
    'EmailClientListResult',
    'EmailClient',
    'PreviewRequestOptions'
]



class Device(object):
    """Device.

    :param id: Unique identifier for the device.
    :type id: str
    :param name: The name of the device.
    :type name: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.id = data.get('id', None)
        self.name = data.get('name', None)



class MessageAddress(object):
    """MessageAddress.

    :param name: Display name, if one is specified.
    :type name: str
    :param email: Email address (applicable to email messages).
    :type email: str
    :param phone: Phone number (applicable to SMS messages).
    :type phone: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.name = data.get('name', None)
        self.email = data.get('email', None)
        self.phone = data.get('phone', None)



from mailosaur.operations.analysis_operations import AnalysisOperations
from mailosaur.operations.files_operations import FilesOperations
from mailosaur.operations.messages_operations import MessagesOperations
from mailosaur.operations.servers_operations import ServersOperations
from mailosaur.operations.devices_operations import DevicesOperations
from mailosaur.operations.previews_operations import PreviewsOperations

__all__ = [
    'AnalysisOperations',
    'FilesOperations',
    'MessagesOperations',
    'ServersOperations',
    'DevicesOperations',
    'PreviewsOperations'
]



import os
from unittest import TestCase
from .mailer import Mailer
from mailosaur import MailosaurClient
from mailosaur.models import SearchCriteria, MailosaurException

class EmailsTest(TestCase):
    @classmethod
    def setUpClass(cls):
        api_key = os.getenv('MAILOSAUR_API_KEY')
        base_url = os.getenv('MAILOSAUR_BASE_URL')
        cls.server = os.getenv('MAILOSAUR_SERVER')

        if (api_key or cls.server) is None:
            raise Exception("Missing necessary environment variables - refer to README.md")

        cls.client = MailosaurClient(api_key, base_url)

        cls.client.messages.delete_all(cls.server)

        host = os.getenv('MAILOSAUR_SMTP_HOST', 'mailosaur.net')
        test_email_address = "files_test@%s.%s" % (cls.server, host)

        Mailer.send_email(cls.client, cls.server, test_email_address)

        criteria = SearchCriteria()
        criteria.sent_to = test_email_address
        cls.email = cls.client.messages.get(cls.server, criteria)

    def test_get_email(self):
        result = self.client.files.get_email(self.email.id)
        content = b''.join(result).decode('utf-8')
        self.assertIsNotNone(content)
        self.assertTrue(len(content) > 1)
        self.assertTrue(self.email.subject in content)
    
    def test_get_attachment(self):
        attachment = self.email.attachments[0]
        result = self.client.files.get_attachment(attachment.id)
        self.assertIsNotNone(result)

        file_length = 0
        for i in result:
            file_length += len(i)
        self.assertEqual(attachment.length, file_length)

if __name__ == '__main__':
    unittest.main()



import pytest
import os
from unittest import TestCase
import string
import random
from .mailer import Mailer
from mailosaur import MailosaurClient
from mailosaur.models import SearchCriteria, PreviewRequestOptions, MailosaurException


class PreviewsTest(TestCase):
    @classmethod
    def setUpClass(cls):
        api_key = os.getenv('MAILOSAUR_API_KEY')
        base_url = os.getenv('MAILOSAUR_BASE_URL')
        cls.server = os.getenv('MAILOSAUR_SERVER')

        if api_key is None or cls.server is None:
            raise Exception(
                "Missing necessary environment variables - refer to README.md")

        cls.client = MailosaurClient(api_key, base_url)

    def test_list_clients(self):
        result = self.client.previews.list_email_clients()
        self.assertIsNotNone(result.items)
        self.assertTrue(len(result.items) > 1)

    def test_generate_previews(self):
        random_string = ''.join(random.choice(
            string.ascii_uppercase + string.ascii_lowercase) for _ in range(10))
        host = os.getenv('MAILOSAUR_SMTP_HOST', 'mailosaur.net')
        test_email_address = "%s@%s.%s" % (
            random_string, self.server, host)

        Mailer.send_email(self.client, self.server, test_email_address)

        criteria = SearchCriteria()
        criteria.sent_to = test_email_address
        email = self.client.messages.get(self.server, criteria)

        options = PreviewRequestOptions(["iphone-16plus-applemail-lightmode-portrait"])

        result = self.client.messages.generate_previews(
            email.id, options)

        self.assertIsNotNone(result.items)
        self.assertTrue(len(result.items) > 0)

        # Ensure we can download one of the generated preview
        file = self.client.files.get_preview(result.items[0].id)
        self.assertIsNotNone(file)


if __name__ == '__main__':
    unittest.main()



import os
import random
import string
from ..models import ServerListResult
from ..models import Server
from ..models import MailosaurException

class ServersOperations(object):
    """ServersOperations operations.
    """

    def __init__(self, session, base_url, handle_http_error):
        self.session = session
        self.base_url = base_url
        self.handle_http_error = handle_http_error

    def generate_email_address(self, server):
        host = os.getenv('MAILOSAUR_SMTP_HOST', 'mailosaur.net')
        randomString = ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(10))
        return "%s@%s.%s" % (randomString, server, host)

    def list(self):
        """List all servers.

        Returns a list of your virtual SMTP servers. Servers are returned
        sorted in alphabetical order.

        :return: ServerListResult
        :rtype: ~mailosaur.models.ServerListResult
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/servers" % (self.base_url)
        response = self.session.get(url)
        
        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        data = response.json()

        return ServerListResult(data)

    def create(self, server_create_options):
        """Create a server.

        Creates a new virtual SMTP server and returns it.

        :param server_create_options:
        :type server_create_options: ~mailosaur.models.ServerCreateOptions
        :return: Server
        :rtype: ~mailosaur.models.Server
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/servers" % (self.base_url)
        response = self.session.post(url, json=server_create_options.to_json())
        
        if response.status_code not in [200]:
            self.handle_http_error(response)
            return
        
        data = response.json()

        return Server(data)

    def get(self, id):
        """Retrieve a server.

        Retrieves the detail for a single server. Simply supply the unique
        identifier for the required server.

        :param id: The identifier of the server to be retrieved.
        :type id: str        
        :return: Server
        :rtype: ~mailosaur.models.Server
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/servers/%s" % (self.base_url, id)
        response = self.session.get(url)

        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        data = response.json()

        return Server(data)

    def get_password(self, id):
        """Retrieve server password.

        Retrieves the password for use with SMTP and POP3 for a single server. 
        Simply supply the unique identifier for the required server.

        :param id: The identifier of the server.
        :type id: str
        :return: str
        :rtype: str
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/servers/%s/password" % (self.base_url, id)
        response = self.session.get(url)

        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        data = response.json()

        return data.get('value', None)

    def update(
            self, id, server):
        """Update a server.

        Updats a single server and returns it.

        :param id: The identifier of the server to be updated.
        :type id: str
        :param server:
        :type server: ~mailosaur.models.Server
        :param dict custom_headers: headers that will be added to the request
        :return: Server
        :rtype: ~mailosaur.models.Server
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/servers/%s" % (self.base_url, id)
        response = self.session.put(url, json=server.to_json())
        
        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        data = response.json()

        return Server(data)

    def delete(
            self, id):
        """Delete a server.

        Permanently deletes a server. This operation cannot be undone. Also
        deletes all messages and associated attachments within the server.

        :param id: The identifier of the server to be deleted.
        :type id: str        
        :return: None
        :rtype: None
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/servers/%s" % (self.base_url, id)
        response = self.session.delete(url)
        
        if response.status_code not in [204]:
            self.handle_http_error(response)
            return



import json


class MessageCreateOptions(object):
    """MessageCreateOptions.

    :param to: The email address to which the email will be sent. Must be a verified email address.
    :type to: str
    :param cc: The email address to which the email will be CC'd. Must be a verified email address.
    :type cc: str
    :param send: If true, email will be sent upon creation.
    :type send: bool
    :param subject: The email subject line.
    :type subject: str
    :param text: The plain text body of the email. Note that only text or html can be supplied, not both.
    :type text: str
    :param html: The HTML body of the email. Note that only text or html can be supplied, not both.
    :type html: str
    :param attachments: Any message attachments.
    :type attachments: list[~mailosaur.models.Attachment]
    :param sendFrom: Allows for the partial override of the message's 'from' address. This **must** be an
     address ending with `YOUR_SERVER.mailosaur.net`, such as `my-emails@a1bcdef2.mailosaur.net`.
    :type sendFrom: str
    """

    def __init__(self, to, send, subject, text=None, html=None, attachments=None, sendFrom=None, cc=None):
        self.to = to
        self.cc = cc
        self.send = send
        self.subject = subject
        self.text = text
        self.html = html
        self.attachments = attachments
        self.sendFrom = sendFrom

    def to_json(self):
        attachments = []

        if self.attachments is not None:
            for a in self.attachments:
                attachments.append(a.to_json())

        return {
            'to': self.to,
            'cc': self.cc,
            'from': self.sendFrom,
            'send': self.send,
            'subject': self.subject,
            'text': self.text,
            'html': self.html,
            'attachments': attachments
        }



class ServerListResult(object):
    """The result of a server listing request.

    :param items: The individual servers forming the result. Servers are
     returned sorted by creation date, with the most recently-created server
     appearing first.
    :type items: list[~mailosaur.models.Server]
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.items = data.get('items', None)



class Link(object):
    """Link.

    :param href:
    :type href: str
    :param text:
    :type text: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}
            
        self.href = data.get('href', None)
        self.text = data.get('text', None)



import json


class PreviewRequestOptions(object):
    """PreviewRequestOptions.

    :param email_clients: The list email clients to generate previews with.
    :type email_clients: list[str]
    """

    def __init__(self, email_clients=None):
        self.email_clients = email_clients

    def to_json(self):
        return {
            'emailClients': self.email_clients
        }



class MessageForwardOptions(object):
    """MessageForwardOptions.

    :param to: The email address to which the email will be sent. Must be a verified email address.
    :type to: str
    :param cc: The email address to which the email will be CC'd. Must be a verified email address.
    :type cc: str
    :param text: Any additional plain text content to forward the email with. Note that only text or html can be supplied, not both.
    :type text: str
    :param html: Any additional HTML content to forward the email with. Note that only html or text can be supplied, not both.
    :type html: str
    """

    def __init__(self, to, text=None, html=None, cc=None):
        self.to = to
        self.cc = cc
        self.text = text
        self.html = html

    def to_json(self):
        return {
            'to': self.to,
            'cc': self.cc,
            'text': self.text,
            'html': self.html
        }



class Code(object):
    """Code.

    :param value:
    :type value: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.value = data.get('value', None)



class MailosaurException(Exception):
    """MailosaurException.

    :param message:
    type message: str
    :param error_type:
    :type error_type: str
    :param http_status_code:
    :type http_status_code: int
    :param http_response_body:
    :type http_response_body: str
    """

    def __init__(self, message, error_type, http_status_code = None, http_response_body = None):
        super(MailosaurException, self).__init__(message)
        self.message = message
        self.error_type = error_type
        self.http_status_code = http_status_code
        self.http_response_body = http_response_body
 


class Image(object):
    """Image.

    :param src:
    :type src: str
    :param alt:
    :type alt: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}
            
        self.src = data.get('src', None)
        self.alt = data.get('alt', None)



class Attachment(object):
    """Describes a message attachment.

    :param id: Unique identifier for the attachment.
    :type id: str

    :param content_type: The MIME type of the attachment.
    :type content_type: str

    :param file_name: The filename of the attachment.
    :type file_name: str

    :param content: The base64-encoded content of the attachment. Note: This is only populated when sending attachments.
    :type content: str

    :param content_id: The content identifier (for attachments that are embedded within the body of the message).
    :type content_id: str
    :param length: The file size, in bytes.
    :type length: int
    :param url: The URL from which the attachment can be downloaded.
    :type url: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.id = data.get('id', None)
        self.content_type = data.get('contentType', None)
        self.file_name = data.get('fileName', None)
        self.content_id = data.get('contentId', None)
        self.content = data.get('content', None)
        self.length = data.get('length', None)
        self.url = data.get('url', None)

    def to_json(self):
        return {
            'contentType': self.content_type,
            'fileName': self.file_name,
            'contentId': self.content_id,
            'content': self.content
        }



from .result_enum import ResultEnum

class BlockListResult(object):
    """BlockListResult.

    :param id:
    :type id: string
    :param name:
    :type name: string
    :param result:
    :type result: ~mailosaur.models.ResultEnum
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.id = data.get('id', None)
        self.name = data.get('name', None)
        self.result = ResultEnum(data.get('result', None))



from ..models import MailosaurException
import time
from datetime import datetime


class FilesOperations(object):
    """FilesOperations operations.
    """

    def __init__(self, session, base_url, handle_http_error):
        self.session = session
        self.base_url = base_url
        self.handle_http_error = handle_http_error

    def get_attachment(self, id):
        """Download an attachment.

        Downloads a single attachment. Simply supply the unique identifier for
        the required attachment.

        :param id: The identifier of the attachment to be downloaded.
        :type id: str
        :return: object
        :rtype: Generator
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        url = "%sapi/files/attachments/%s" % (self.base_url, id)
        response = self.session.get(url, stream=True)

        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        return response

    def get_email(self, id):
        """Download EML.

        Downloads an EML file representing the specified email. Simply supply
        the unique identifier for the required email.

        :param id: The identifier of the email to be downloaded.
        :type id: str
        :return: object
        :rtype: Generator
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        url = "%sapi/files/email/%s" % (self.base_url, id)
        response = self.session.get(url, stream=True)

        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        return response

    def get_preview(self, id):
        """Download an email preview.

        Downloads a screenshot of your email rendered in a real email client. Simply supply
        the unique identifier for the required preview.

        :param id: The identifier of the email preview to be downloaded.
        :type id: str
        :return: object
        :rtype: Generator
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        timeout = 120000
        poll_count = 0
        start_time = datetime.today()

        while True:
            url = "%sapi/files/screenshots/%s" % (self.base_url, id)
            response = self.session.get(url, stream=True)

            if response.status_code == 200:
                return response

            if response.status_code not in [202]:
                self.handle_http_error(response)
                return

            # List conversion necessary for Python 3 compatibility
            # https://stackoverflow.com/questions/36982858/object-of-type-map-has-no-len-in-python-3
            delay_pattern = list(
                map(int, (response.headers.get('x-ms-delay') or '1000').split(',')))

            delay = delay_pattern[len(
                delay_pattern) - 1] if poll_count >= len(delay_pattern) else delay_pattern[poll_count]

            poll_count += 1

            # Stop if timeout will be exceeded
            if ((1000 * (datetime.today() - start_time).total_seconds()) + delay) > timeout:
                raise MailosaurException(
                    "An email preview was not generated in time. The email client may not be available, or the preview ID [%s] may be incorrect." % id, "preview_timeout")

            time.sleep(delay / 1000)



class EmailClient(object):
    """Describes an email client with which email previews can be generated.

    :param label: The unique email client label. Used when generating email preview requests.
    :type label: str

    :param name: The display name of the email client.
    :type name: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.label = data.get('label', None)
        self.name = data.get('name', None)

    def to_json(self):
        return {
            'label': self.label,
            'name': self.name
        }



from .email_authentication_result import EmailAuthenticationResult
from .block_list_result import BlockListResult
from .content import Content
from .dns_records import DnsRecords
from .spam_assassin_result import SpamAssassinResult

class DeliverabilityReport(object):
    """DeliverabilityReport.

    :param spf:
    :type spf: ~mailosaur.models.EmailAuthenticationResult
    :param dkim:
    :type dkim: list[~mailosaur.models.EmailAuthenticationResult]
    :param dmarc:
    :type dmarc: ~mailosaur.models.EmailAuthenticationResult
    :param block_list:
    :type block_lists: list[~mailosaur.models.BlockListResult]
    :param content:
    :type content: ~mailosaur.models.Content
    :param dns_records:
    :type dns_records: ~mailosaur.models.DnsRecords
    :param spam_assassin:
    :type spam_assassin: ~mailosaur.models.SpamAssassinResult
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.spf = EmailAuthenticationResult(data.get('spf', None))
        self.dkim = [EmailAuthenticationResult(i) for i in data.get('dkim', None)]
        self.dmarc = EmailAuthenticationResult(data.get('dmarc', None))
        self.block_lists = [BlockListResult(i) for i in data.get('blockLists', None)]
        self.content = Content(data.get('content', None))
        self.dns_records = DnsRecords(data.get('dnsRecords', None))
        self.spam_assassin = SpamAssassinResult(data.get('spamAssassin', None))



from ..models import SpamAnalysisResult
from ..models import MailosaurException
from ..models import DeliverabilityReport

class AnalysisOperations(object):
    """AnalysisOperations operations.
    """

    def __init__(self, session, base_url, handle_http_error):
        self.session = session
        self.base_url = base_url
        self.handle_http_error = handle_http_error

    def spam(self, email):
        """Perform a spam test.

        Perform spam testing on the specified email.

        :param email: The identifier of the email to be analyzed.
        :type email: str        
        :return: SpamAnalysisResult
        :rtype: ~mailosaur.models.SpamAnalysisResult
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/analysis/spam/%s" % (self.base_url, email)
        response = self.session.get(url)
        
        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        data = response.json()

        return SpamAnalysisResult(data)

    def deliverability(self, email):
        """Perform a deliverability test.

        Perform deliverability testing on the specified email.

        :param email: The identifier of the email to be analyzed.
        :type email: str        
        :return: DeliverabilityReport
        :rtype: ~mailosaur.models.DeliverabilityReport
        :raises:
         :class:`MailosaurException<mailosaur.models.MailosaurException>`
        """
        url = "%sapi/analysis/deliverability/%s" % (self.base_url, email)
        response = self.session.get(url)
        
        if response.status_code not in [200]:
            self.handle_http_error(response)
            return

        data = response.json()

        return DeliverabilityReport(data)




import json


class MessageReplyOptions(object):
    """MessageReplyOptions.

    :param cc: The email address to which the email will be CC'd. Must be a verified email address.
    :type cc: str
    :param text: Any additional plain text content to include in the reply. Note that only text or html can be supplied, not both.
    :type text: str
    :param html: Any additional HTML content to include in the reply. Note that only html or text can be supplied, not both.
    :type html: str
    :param attachments: Any message attachments.
    :type attachments: list[~mailosaur.models.Attachment]
    """

    def __init__(self, text=None, html=None, attachments=None, cc=None):
        self.cc = cc
        self.text = text
        self.html = html
        self.attachments = attachments

    def to_json(self):
        attachments = []

        if self.attachments is not None:
            for a in self.attachments:
                attachments.append(a.to_json())

        return {
            'cc': self.cc,
            'text': self.text,
            'html': self.html,
            'attachments': attachments
        }



from .preview import Preview


class PreviewListResult(object):
    """A list of requested email previews.

    :param items: The summaries for each requested preview.
    :type items: list[~mailosaur.models.Preview]
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.items = [Preview(i) for i in data.get('items', None)]



from setuptools import setup, find_packages

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='mailosaur',
    version='8.0.0',
    description='The Mailosaur Python library lets you integrate email and SMS testing into your continuous integration process.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Mailosaur Ltd',
    author_email='code@mailosaur.com',
    url='https://github.com/mailosaur/mailosaur-python',
    license='MIT',
    keywords='email sms testing automation selenium robot framework',
    packages=find_packages(),
    zip_safe=False, requires=['requests'],
    install_requires=[
        'python-dateutil',
        'tzlocal',
        'requests',
        'requests[security]'
    ],
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*',
    tests_require=[
        'pytest >= 8.0.0'
    ],
    project_urls={
        'Bug Tracker': 'https://github.com/mailosaur/mailosaur-python/issues',
        'Documentation': 'https://mailosaur.com/docs/email-testing/python/',
        'Source Code': 'https://github.com/mailosaur/mailosaur-python',
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: Quality Assurance',
        'Topic :: Software Development :: Testing',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ]
)



class SearchCriteria(object):
    """SearchCriteria.

    :param sent_from: The full email address from which the target email was sent.
    :type sent_from: str
    :param sent_to: The full email address to which the target email was sent.
    :type sent_to: str
    :param subject: The value to seek within the target email's subject line.
    :type subject: str
    :param body: The value to seek within the target email's HTML or text
     body.
    :type body: str
    :param match: If set to ALL (default), then only results that match all 
     specified criteria will be returned. If set to ANY, results that match any of the
     specified criteria will be returned.
    :type body: str
    """

    def __init__(self):
        self.sent_from = None
        self.sent_to = None
        self.subject = None
        self.body = None
        self.match = "ALL"

    def to_json(self):
        return {
            'sentFrom': self.sent_from,
            'sentTo': self.sent_to,
            'subject': self.subject,
            'body': self.body,
            'match': self.match
        }



from .link import Link
from .code import Code
from .image import Image


class MessageContent(object):
    """MessageContent.

    :param links:
    :type links: list[~mailosaur.models.Link]
    :param codes:
    :type codes: list[~mailosaur.models.Code]
    :param images:
    :type images: list[~mailosaur.models.Image]
    :param body:
    :type body: str
    """

    def __init__(self, data=None):
        if data is None:
            data = {}

        self.links = [Link(i) for i in data.get('links', [])]
        self.codes = [Code(i) for i in data.get('codes', [])]

        images = data.get('images', None)
        if isinstance(images, list):
            self.images = [Image(i) for i in images]

        self.body = data.get('body', None)
